==> haskell-distributive-0.5.3-16-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-distributive.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: distributive
version: 0.5.3
id: distributive-0.5.3-IdldapDLIRvIkayXxqE7xM
key: distributive-0.5.3-IdldapDLIRvIkayXxqE7xM
license: BSD-3-Clause
copyright: Copyright (C) 2011-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/distributive/
synopsis: Distributive functors -- Dual to Traversable
description:
    Distributive functors -- Dual to Traversable
category: Data Structures
abi: 80163a307d44ca5380cd7f4342768aa0
exposed: True
exposed-modules:
    Data.Distributive Data.Distributive.Generic
import-dirs: /usr/lib/ghc-8.4.3/site-local/distributive-0.5.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/distributive-0.5.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/distributive-0.5.3
hs-libraries: HSdistributive-0.5.3-IdldapDLIRvIkayXxqE7xM
depends:
    base-4.11.1.0 base-orphans-0.8-3Ndp0ohh7rtBqRP3qW2F5j
    transformers-0.5.5.0
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             base-orphans-0.8-3Ndp0ohh7rtBqRP3qW2F5j=a0188b579af839f9c8290c33a86ab883
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=197a030c492741542d6f49bc76370bb8
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=4bf567357cce5e796341c1faefad6985
haddock-interfaces: /usr/share/doc/haskell-distributive/html/distributive.haddock
haddock-html: /usr/share/doc/haskell-distributive/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-distributive-0.6-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-distributive.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: distributive
version: 0.6
id: distributive-0.6-IsVyilunZgICGjJYT3RUw
key: distributive-0.6-IsVyilunZgICGjJYT3RUw
license: BSD-3-Clause
copyright: Copyright (C) 2011-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/distributive/
synopsis: Distributive functors -- Dual to Traversable
description:
    Distributive functors -- Dual to @Traversable@
category: Data Structures
abi: f5bbf892f75e5889cad5d363c52f11d6
exposed: True
exposed-modules:
    Data.Distributive Data.Distributive.Generic
import-dirs: /usr/lib/ghc-8.4.3/site-local/distributive-0.6
library-dirs: /usr/lib/ghc-8.4.3/site-local/distributive-0.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/distributive-0.6
hs-libraries: HSdistributive-0.6-IsVyilunZgICGjJYT3RUw
depends:
    base-4.11.1.0 base-orphans-0.8-DMkdJwLFak2DoFZzwzdOJW
    transformers-0.5.5.0 tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             base-orphans-0.8-DMkdJwLFak2DoFZzwzdOJW=8fdd269bb784bcdf160da8c61c0e0531
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=4bf567357cce5e796341c1faefad6985
haddock-interfaces: /usr/share/doc/haskell-distributive/html/distributive.haddock
haddock-html: /usr/share/doc/haskell-distributive/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
